.. _api:

API Reference
=============


.. autofunction:: zulu.now


.. autofunction:: zulu.create


.. autofunction:: zulu.parse


.. autofunction:: zulu.range


.. autofunction:: zulu.span_range


.. autofunction:: zulu.parse_delta


.. autofunction:: zulu.delta


.. autoclass:: zulu.Zulu
    :members:
    :inherited-members:


.. autoclass:: zulu.Delta
    :members:
    :inherited-members:


.. autoclass:: zulu.ParseError
